@@ -11,7 +11,7 @@ use Kossy::BodyParser::UrlEncoded;
 use Kossy::BodyParser::MultiPart;
 use Kossy::BodyParser::JSON;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 sub new {
     my($class, $env, %opts) = @_;
@@ -24,6 +24,12 @@ sub new {
     }, $class;
 }
 
+sub new_response {
+    my $self = shift;
+    require Kossy::Response;
+    Kossy::Response->new(@_);
+}
+
 sub request_body_parser {
     my $self = shift;
     unless (exists $self->{request_body_parser}) {
